{% extends "admin/base_site.html" %}
{% load i18n static %}

{% block content %}
<div id="content-main">
    <p>{% trans '您暂时不能访问该站点的后台管理，这是以下原因造成的：' %}</p>
    <ul>
    {% if user.is_anonymous %}
        <li>{% trans '你还没登录，请重新刷新页面！' %}</li>
    {% else %}
        {% if not user.is_active %}
            <li>{% trans '用户' %}（<strong>{{ user.username }}</strong>）{% trans '未激活！' %}</li>
        {% else %}{% if not user.is_staff %}
            <li>{% trans '用户' %}（<strong>{{ user.username }}</strong>）{% trans '没有管理员权限，请联系管理员！' %}</li>
        {% endif %}{% endif %}
    {% endif %}
    </ul>
    <p>{% trans '如有需要，请联系管理员或开发者为您解决上述问题。' %}</p>
</div>
{% endblock %}