.code-editor[data-v-526c82ea]{height:100%}.full-code-editor[data-v-7f72f1ec]{background:#fff}.full-code-editor.full-status[data-v-7f72f1ec]{position:fixed;top:0;right:0;bottom:0;left:0;height:100vh;z-index:3000}.full-code-editor.full-status .code-editor[data-v-7f72f1ec]{height:calc(100% - 38px);width:100%}.full-code-editor .tool-area[data-v-7f72f1ec]{padding:0 20px;height:38px;line-height:38px;text-align:right;background:#202024}.full-code-editor .tool-area .zoom-icon[data-v-7f72f1ec]{font-size:14px;color:#fff;cursor:pointer}.full-code-editor .code-editor[data-v-7f72f1ec]{width:100%;height:378px}.plugin-debug-panel[data-v-102ad921]{min-width:1366px;height:100%;margin:0 60px;padding:70px 0 30px;display:flex;flex-direction:column}.debug-panel-version[data-v-102ad921]{position:absolute;left:0;top:0;height:52px;width:100%;line-height:52px;padding-left:20px;color:#666;font-size:16px;font-weight:700;background:#fff;margin-bottom:20px}.storage-wrap[data-v-102ad921]{display:flex;align-items:center}.storage-wrap .bk-select[data-v-102ad921]{margin-right:30px}.storage-wrap .label[data-v-102ad921]{flex-shrink:0;margin-right:10px;font-size:14px;color:#63656e}.storage-wrap .bk-form-radio[data-v-102ad921]{margin-right:20px}.content-wrapper[data-v-102ad921]{max-height:calc(100% - 62px);display:flex;justify-content:space-between;margin-top:30px}.content-wrapper .left-content[data-v-102ad921]{display:flex;flex-direction:column;width:53%;margin-right:20px}.content-wrapper .left-content .scroll-wrapper[data-v-102ad921]{min-height:430px;overflow-y:scroll}.content-wrapper .left-content .scroll-wrapper[data-v-102ad921]::-webkit-scrollbar{width:3px;height:6px}.content-wrapper .left-content .scroll-wrapper[data-v-102ad921]::-webkit-scrollbar-thumb{border-radius:20px;background:#dcdee5;box-shadow:inset 0 0 6px hsla(0,0%,80%,.3)}.content-wrapper .left-content .context-form-item[data-v-102ad921]{display:flex;align-items:center;font-size:14px;margin-bottom:15px;color:#666}.content-wrapper .left-content .context-form-item label[data-v-102ad921]{min-width:85px;flex-shrink:0}.content-wrapper .left-content .context-form-item[data-v-102ad921]:last-child{margin-bottom:0}.content-wrapper .right-content[data-v-102ad921]{flex-shrink:0;width:46%;height:100%}.content-wrapper .right-content .execution-info-item[data-v-102ad921]{display:flex;align-items:center;font-size:14px;line-height:22px;margin-bottom:15px;color:#666}.content-wrapper .right-content .execution-info-item label[data-v-102ad921]{flex-shrink:0}.content-wrapper .right-content .execution-info-item .info-desc[data-v-102ad921]{flex:1;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.content-wrapper .right-content .execution-info-item[data-v-102ad921]:last-child{margin-bottom:0}.content-wrapper .right-content .execution-info-item:last-child label[data-v-102ad921]{align-self:flex-start}.content-wrapper .left-content .scroll-wrapper>[data-v-102ad921],.content-wrapper .right-content>[data-v-102ad921]{min-height:200px;padding:20px;background:#fff}.content-wrapper .left-content .scroll-wrapper .left-content-top[data-v-102ad921],.content-wrapper .left-content .scroll-wrapper .right-content-top[data-v-102ad921],.content-wrapper .right-content .left-content-top[data-v-102ad921],.content-wrapper .right-content .right-content-top[data-v-102ad921]{margin-bottom:30px}.execution-btn[data-v-102ad921]{flex-shrink:0;width:80px;margin:30px auto 0}.bk-select[data-v-102ad921]{flex-shrink:0;background:#fff}.bk-select.is-disabled[data-v-102ad921]{background:#fafbfd}.output-edit{width:calc(100% - 70px)}.output-edit .code-editor{height:100px!important}